.. index::
   single: pserve; --help

.. _pserve_script:

.. autoprogram:: pyramid.scripts.pserve:PServeCommand.parser
    :prog: pserve

.. seealso:: :ref:`running_the_project_application` and :ref:`running-pscripts`.
